@@ -8,7 +8,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(main);
-our $VERSION = '0.4.0';
+our $VERSION = '0.01';
 
 use Data::Dumper;
 
@@ -31,23 +31,12 @@ specify it if you want to increase the verbosity.
 
 E.g.:
 
- perl -MNet::Analysis -e main TCP,v=1  dump.tcp    # basic TCP info
- perl -MNet::Analysis -e main HTTP,v=1 dump.tcp    # simple HTTP summary
+ perl -MNet::Analysis -e main TCP,v=1  dump.tcp    - basic TCP info
+ perl -MNet::Analysis -e main HTTP,v=1 dump.tcp    - simple HTTP summary
 
 Only the TCP and HTTP protocols are present in the base distribution; a few
 others are available as separate modules.
 
-EXPERIMENTAL: You can also use live network capture, if you provide a tcpdump
-compatible capture filter instead of a filename:
-
- perl -MNet::Analysis -e main TCP,v=1  "port 80"
-
-Live capture requires a space in the final argument; else it will be assumed
-to be a file to load.
-
-Live capture has the same permissions issues as running tcpdump; you'll
-probably need to run it as root, which you do at your own risk.
-
 EO
     exit 0;
 }
@@ -61,11 +50,13 @@ sub main {
 
     usage() if (grep {/help/} @monitors);
 
-    my ($target) = pop (@monitors);
+    my ($filename) = pop (@monitors);
 
     # Autoload TCP, else other protos won't get much to analyse
     push (@monitors, "TCP") if (! grep {/^TCP/} @monitors);
 
+    die "could not read file '$filename'\n" if (! -r $filename);
+
     my ($d)     = Net::Analysis::Dispatcher->new();
     my ($el)    = Net::Analysis::EventLoop->new (dispatcher => $d);
 
@@ -90,15 +81,7 @@ sub main {
             || die "$mod->new() failed\n";
     }
 
-    if ($target =~ / /) {
-        # Assume a filter string, for live capture
-        print "(starting live capture)\n";
-        $el->loop_net (filter => $target);
-    } else {
-        # A file to be loaded
-        die "could not read file '$target'\n" if (! -r $target);
-        $el->loop_file (filename => $target);
-    }
+    $el->loop_file (filename => $filename);
 }
 
 # }}}
@@ -114,16 +97,12 @@ Net::Analysis - Modules for analysing network traffic
 
 =head1 SYNOPSIS
 
-Using an existing analyser on a tcpdump/wireshark capture file:
+Using a builtin analyser:
 
  $ perl -MNet::Analysis -e main help
- $ perl -MNet::Analysis -e main TCP,v=1            dump.tcp # basic TCP info
- $ perl -MNet::Analysis -e main HTTP,v=1           dump.tcp # HTTP stuff
- $ perl -MNet::Analysis -e main Example2,regex=img dump.tcp # run an example
 
-Or trying live capture:
-
- # perl -MNet::Analysis -e main TCP,v=1            "port 80"
+ $ perl -MNet::Analysis -e main TCP,v=1  dump.tcp    - basic TCP info
+ $ perl -MNet::Analysis -e main HTTP,v=1 dump.tcp    - HTTP stuff
 
 Writing your own analyser:
 
@@ -180,8 +159,7 @@ So here it is. Net::Analysis is a stack of protocol handlers that emit, and
 listen for, events.
 
 At the bottom level, a combination of L<Net::Pcap> and L<NetPacket> emit
-C<tcp_packet> events as they are read from the input file (or live capture from
-a network device.)
+C<tcp_packet> events as they are read from the input file.
 
 The TCP listener (L<Net::Analysis::Listener::TCP>) picks up these packets, and
 reconstructs TCP streams; in turn, it emits C<tcp_monologue> events. A
@@ -248,28 +226,23 @@ C<http_transaction> - a request and its response
 
 =back
 
-=head1 WHERE NEXT
+See the L<Net::Analysis::Listener::HTTPClientPerf> module for a listener which
+builds on the HTTP listener to create some pretty graphics.
 
-To look at how to invoke the whole thing, to plug into your own script, see the
-C<main()> method in L<Net::Analysis>.
+Or the L<Net::Analysis::Listener::Corba> module for one that builds on the
+TCP monologues to provide some profiling info on Corba requests.
 
-To see how to emit (and catch) your own events, look at
-L<Net::Analysis::Listener::Example1>.
+If you want to write your own listener, the Example one should get you started,
+or the HTTP one is a good one to clone.
 
-For a simple example that greps TCP monologue data, see
-L<Net::Analysis::Listener::Example2>.
-
-For a simple example that looks at the HTTP objects emitted for each HTTP
-transaction, see L<Net::Analysis::Listener::Example3>.
-
-To look at how to write a listener that maintains session state, see
-L<Net::Analysis::Listener::HTTP>.
+Finally, look at the C<main()> method in L<Net::Analysis> to see how to setup
+and invoke all the listeners in your own scripts.
 
 =head1 TODO
 
-Performance - this may not be fast enough to handle busy servers in real time.
+Reliability - to date, only used by me. Exposure to weirder data needed !
 
-More work on live capture, this is still experimental.
+Performance - this suite is not suitable for real-time analysis of servers.
 
 UDP support
 
@@ -281,11 +254,9 @@ Move TCP reassembly to Net::LibNIDS ?
 
 =head1 SEE ALSO
 
-L<Net::Analysis::Listener::Example1>,
-L<Net::Analysis::Listener::Example2>,
-L<Net::Analysis::Listener::Example3>,
-L<Net::Analysis::Listener::HTTPClientPerf>,
-L<Net::Pcap>, L<NetPacket>.
+L<Net::Anaylsis::Listener::Example>,
+L<Net::Anaylsis::Listener::HTTPClientPerf>,
+L<Net::Anaylsis::Listener::Corba>, L<Net::Pcap>, L<NetPacket>.
 
 =head1 AUTHOR
 
